import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';

class SimpleTrackingScreen extends StatefulWidget {
  const SimpleTrackingScreen({Key? key}) : super(key: key);

  @override
  State<SimpleTrackingScreen> createState() => _SimpleTrackingScreenState();
}

class _SimpleTrackingScreenState extends State<SimpleTrackingScreen> {
  Object? _response;

  @override
  void initState() {
    super.initState();
    _setupTracking();
  }

  void _setupTracking() {
    G1SDK
        .setupSDK(
      Constant.getEnv(),
      Constant.getWorkSpaceId(),
      isShowLog: true,
    )
        .then((isSetupSuccess) {
      Utils.log("_setupTracking isSetupSuccess $isSetupSuccess");
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          leading: IconButton(
            icon: const Icon(Icons.arrow_back_ios, color: Colors.white),
            onPressed: () {
              Get.back();
            },
          ),
          centerTitle: true,
          title: const Text('SimpleTrackingScreen'),
        ),
        body: Container(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              FutureBuilder<String?>(
                future: G1SDK.platformVersion,
                builder: (_, snapshot) {
                  return Text(snapshot.data ?? '');
                },
              ),
              SampleButton(
                text: "Send event 1",
                onPressed: () {
                  _trackEvent1();
                },
              ),
              SampleButton(
                text: "Send event 2",
                onPressed: () {
                  _trackEvent2();
                },
              ),
              const SizedBox(height: 32.0),
              const Text('>>>RESPONSE'),
              const SizedBox(height: 16.0),
              if (_response != null)
                Expanded(
                  child: ListView(
                    children: [
                      Text(Utils.getPrettyString(_response)),
                    ],
                  ),
                ),
            ],
          ),
        ),
      ),
    );
  }

  void _trackEvent1() {
    _displayResponse(null);
    var profile = <Map>[];
    profile.add({
      "name": "Loitp Flutter",
    });
    G1SDK.trackEvent(
      Constant.getWorkSpaceId(),
      {
        "phone": "0766040293",
        "email": "loitp@galaxy.one",
      },
      profile,
      "event_name",
      DateTime.now().millisecondsSinceEpoch,
      {
        "pageTitle": "Passenger Information from Flutter",
        "pagePath": "/home",
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        _displayResponse(value);
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        _displayResponse(value);
      },
    );
  }

  void _trackEvent2() {
    _displayResponse(null);
    var profile = <Map>[];
    profile.add({
      "name": "Loitp Flutter",
    });
    profile.add({
      "name": "Loitp Flutter 2",
    });
    profile.add({
      "name": "Loitp Flutter 3",
    });
    G1SDK.trackEvent(
      Constant.getWorkSpaceId(),
      {
        "phone": "0766040293",
        "email": "loitp@galaxy.one",
      },
      profile,
      "track_now_event",
      DateTime.now().millisecondsSinceEpoch,
      {
        "name": "Loitp Flutter",
        "bod": "01/01/2000",
        "player_id": 123456,
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        _displayResponse(value);
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        _displayResponse(value);
      },
    );
  }

  void _displayResponse(Object? response) {
    setState(() {
      _response = response;
    });
  }
}
